(window.webpackJsonp=window.webpackJsonp||[]).push([[96],{sDlW:function(e,n){ace.define("ace/snippets/json",["require","exports","module"],(function(e,n,s){"use strict";n.snippetText=void 0,n.scope="json"}))}}]);
//# sourceMappingURL=96.3b87c7ad03e52dfc5e30.js.map